// ============================================================================
// ==                                                                        ==
// == AMDiS - Adaptive multidimensional simulations                          ==
// ==                                                                        ==
// ==  http://www.amdis-fem.org                                              ==
// ==                                                                        ==
// ============================================================================
//
// Software License for AMDiS
//
// Copyright (c) 2010 Dresden University of Technology 
// All rights reserved.
// Authors: Simon Vey, Thomas Witkowski et al.
//
// This file is part of AMDiS
//
// See also license.opensource.txt in the distribution.



/** \file AMDiS.h */

#ifndef AMDIS_H
#define AMDIS_H

#include "stdint.h"
#include "MTL4Types.h"
#include "AbstractFunction.h"
#include "AdaptInfo.h"
#include "AdaptInstationary.h"
#include "AdaptStationary.h"
#include "Assembler.h"
#include "BasisFunction.h"
#include "Boundary.h"
#include "Boundary.h"
#include "BoundaryCondition.h"
#include "BoundaryManager.h"
#include "CoarseningManager.h"
#include "CoarseningManager1d.h"
#include "CoarseningManager2d.h"
#include "CoarseningManager3d.h"
#include "CreatorInterface.h"
#include "CreatorMap.h"
#include "Debug.h"
#include "DOFAdmin.h"
#include "DOFContainer.h"
#include "DOFIndexed.h"
#include "DOFIterator.h"
#include "DOFMatrix.h"
#include "DOFVector.h"
#include "DirichletBC.h"
#include "DualTraverse.h"
#include "ElInfo.h"
#include "ElInfo1d.h"
#include "ElInfo2d.h"
#include "ElInfo3d.h"
#include "Element.h"
#include "ElementDofIterator.h"
#include "Error.h"
#include "Estimator.h"
#include "FiniteElemSpace.h"
#include "FirstOrderTerm.h"
#include "FixVec.h"
#include "Flag.h"
#include "Global.h"
#include "Initfile.h" // replacement for Parameters.h
#include "ITL_Preconditioner.h"
#include "ITL_Solver.h"
#include "Lagrange.h"
#include "LeafData.h"
#include "Line.h"
#include "MacroElement.h"
#include "Marker.h"
#include "MathFunctions.h"
#include "MatrixVector.h"
#include "Mesh.h"
#include "MeshStructure.h"
#include "ComponentTraverseInfo.h"
#include "OEMSolver.h"
#include "Operator.h"
#include "OperatorTerm.h"
#include "Parametric.h"
#include "PeriodicMap.h"
#include "PeriodicBC.h"
#include "ProblemStat.h"
#include "ProblemInstat.h"
#include "ProblemTimeInterface.h"
#include "ProblemImplicit.h"
#include "ProblemInterpol.h"
#include "ProblemStatBase.h"
#include "SecondOrderTerm.h"
#include "StandardProblemIteration.h"
#include "Projection.h"
#include "QPsiPhi.h"
#include "Quadrature.h"
#include "RCNeighbourList.h"
#include "RefinementManager.h"
#include "RefinementManager1d.h"
#include "RefinementManager2d.h"
#include "RefinementManager3d.h"
#include "RobinBC.h"
#include "SolutionDataStorage.h"
#include "SurfaceOperator.h"
#include "SurfaceQuadrature.h"
#include "SystemVector.h"
#include "Tetrahedron.h"
#include "TimedObject.h"
#include "Traverse.h"
#include "Triangle.h"
#include "VertexVector.h"
#include "ZeroOrderTerm.h"

#include "io/ArhReader.h"
#include "io/ArhWriter.h"
#include "io/FileWriter.h"
#include "io/GNUPlotWriter.h"
#include "io/GridWriter.h"
#include "io/MacroWriter.h"
#include "io/PngWriter.h"
#include "io/PovrayWriter.h"
#include "io/ValueReader.h"
#include "io/ValueWriter.h"
#include "io/VtkWriter.h"

#include "nonlin/ProblemNonLin.h"
#include "nonlin/NonLinSolver.h"

#include "time/RosenbrockAdaptInstationary.h"
#include "time/RosenbrockStationary.h"


#if HAVE_PARALLEL_DOMAIN_AMDIS
#include "parallel/InteriorBoundary.h"
#include "parallel/MpiHelper.h"

#if HAVE_PARALLEL_MTL4
#include "parallel/Mtl4Solver.h"
#else
#include "parallel/PetscProblemStat.h"
#endif

#endif

#endif
